=== modified file 'NEWS'
--- NEWS	2009-02-26 05:41:07 +0000
+++ NEWS	2009-03-17 06:18:30 +0000
@@ -46,11 +46,11 @@
       stream if the server is version 1.13 or greater, reducing roundtrips
       significantly. (Andrew Bennetts, Robert Collins)
 
-    * ``bzr xxx -h`` where xxx is a command now shows concise help, i.e.
-      a usage message and the options without the descriptive sections
-      (like Description and Examples). When concise help is given, a
-      message is given explaining how to see the complete help, i.e.
-      ``bzr help xxx``.  (Ian Clatworthy)
+    * ``bzr xxx --usage`` where xxx is a command now shows a usage
+      message and the options without the descriptive sections
+      (like Description and Examples). A message is also given
+      explaining how to see the complete help, i.e. ``bzr help xxx``.
+      (Ian Clatworthy)
 
     * Lightweight Checkouts and Stacked Branches should both be much
       faster over remote connections. Building the working tree now

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2009-02-26 06:15:24 +0000
+++ bzrlib/commands.py	2009-03-17 06:18:30 +0000
@@ -530,6 +530,9 @@
 
         # Process the standard options
         if 'help' in opts:  # e.g. bzr add --help
+            sys.stdout.write(self.get_help_text())
+            return 0
+        if 'usage' in opts:  # e.g. bzr add --usage
             sys.stdout.write(self.get_help_text(verbose=False))
             return 0
         trace.set_verbosity_level(option._verbosity_level)

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2009-02-23 15:29:35 +0000
+++ bzrlib/option.py	2009-03-17 06:18:30 +0000
@@ -502,6 +502,8 @@
 # Declare the standard options
 _standard_option('help', short_name='h',
                  help='Show help message.')
+_standard_option('usage',
+                 help='Show usage message and options.')
 _standard_option('verbose', short_name='v',
                  help='Display more information.',
                  custom_callback=_verbosity_level_callback)

=== modified file 'bzrlib/tests/blackbox/test_help.py'
--- bzrlib/tests/blackbox/test_help.py	2009-02-26 06:15:24 +0000
+++ bzrlib/tests/blackbox/test_help.py	2009-03-17 06:18:30 +0000
@@ -112,18 +112,10 @@
         self.assertTrue('rocks' in hidden)
         self.assertTrue('rocks' not in commands)
 
-    def test_help_concise(self):
+    def test_help_detail(self):
         dash_h  = self.run_bzr('diff -h')[0]
-        self.assertContainsRe(dash_h, "Purpose:")
-        self.assertContainsRe(dash_h, "Usage:")
-        self.assertContainsRe(dash_h, "Options:")
-        self.assertNotContainsRe(dash_h, "Description:")
-        self.assertNotContainsRe(dash_h, "Examples:")
-        self.assertContainsRe(dash_h, "See also:")
-        self.assertContainsRe(dash_h, "Aliases:")
-
-    def test_help_detail(self):
         help_x  = self.run_bzr('help diff')[0]
+        self.assertEquals(dash_h, help_x)
         self.assertContainsRe(help_x, "Purpose:")
         self.assertContainsRe(help_x, "Usage:")
         self.assertContainsRe(help_x, "Options:")
@@ -132,6 +124,16 @@
         self.assertContainsRe(help_x, "See also:")
         self.assertContainsRe(help_x, "Aliases:")
 
+    def test_help_usage(self):
+        usage  = self.run_bzr('diff --usage')[0]
+        self.assertContainsRe(usage, "Purpose:")
+        self.assertContainsRe(usage, "Usage:")
+        self.assertContainsRe(usage, "Options:")
+        self.assertNotContainsRe(usage, "Description:")
+        self.assertNotContainsRe(usage, "Examples:")
+        self.assertContainsRe(usage, "See also:")
+        self.assertContainsRe(usage, "Aliases:")
+
     def test_help_help(self):
         help = self.run_bzr('help help')[0]
         qmark = self.run_bzr('? ?')[0]

=== modified file 'bzrlib/tests/test_help.py'
--- bzrlib/tests/test_help.py	2009-02-26 06:15:24 +0000
+++ bzrlib/tests/test_help.py	2009-03-17 06:18:30 +0000
@@ -114,6 +114,7 @@
             'Usage:   bzr Demo\n'
             '\n'
             'Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'
@@ -133,6 +134,7 @@
             ':Usage:   bzr Demo\n'
             '\n'
             ':Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'
@@ -167,6 +169,7 @@
             'Usage:   bzr Demo\n'
             '\n'
             'Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'
@@ -185,6 +188,7 @@
             'Usage:   bzr Demo\n'
             '\n'
             'Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'
@@ -218,6 +222,7 @@
             'Usage:   bzr Demo\n'
             '\n'
             'Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'
@@ -260,6 +265,7 @@
             '\n'
             '\n'
             'Options:\n'
+            '  --usage        Show usage message and options.\n'
             '  -v, --verbose  Display more information.\n'
             '  -q, --quiet    Only display errors and warnings.\n'
             '  -h, --help     Show help message.\n'

